@@ -7,8 +7,9 @@ from django.db import models
 class News(models.Model):
     title = models.TextField('Article Title')
     url = models.TextField('Article URL')
-    expiration_date = models.DateTimeField(auto_now_add=True) #compare against this for deleting old rows, +7 from current date
+    expiration_date = models.DateTimeField(auto_now_add=True)
     summary = models.TextField('Article Summary')
+    company = models.TextField('Article Company')
 
 # make table for the preferences of each user, default means they want all news
 # initially set during sign up, toggled with icons on side
@@ -19,3 +20,13 @@ class Preferences(models.Model):
     google = models.BooleanField(default=True)
     facebook = models.BooleanField(default=True)
     microsoft = models.BooleanField(default=True)
+    amazon = models.BooleanField(default=True)
+    samsung = models.BooleanField(default=True)
+    ibm = models.BooleanField(default=True)
+    twitter = models.BooleanField(default=True)
+    netflix = models.BooleanField(default=True)
+    oracle = models.BooleanField(default=True)
+    sap = models.BooleanField(default=True)
+    salesforce = models.BooleanField(default=True)
+    tesla = models.BooleanField(default=True)
+    spacex = models.BooleanField(default=True)
